#!/bin/bash
#
# Simple script to stop (emergency brake) a hanging(?) Amanda task.
# Part of amanda-server-addons package.

AMCHECK="/usr/sbin/amcheck"     # amcheck command call
AMCLEANUP="/usr/sbin/amcleanup"	# amcleanup command call
AWK="/usr/bin/awk"              # awk command call
GREP="/bin/grep"                # grep command call
PS="/bin/ps"                    # ps command call

MSK_AMANDA_STOP_KILLING="Killing process:"
MSG_AMANDA_STOP_USAGE="Usage: $0 Username_running_Amanda_task Amanda_task_name"
MSG_AMANDA_STOP_WRONGUSER="Please run as"

# Getting common variables.
HEADERS="/etc/default/amanda-server-addons"
if [ -f "$HEADERS" ]; then . $HEADERS; fi

# Some local constants (not to override).
runuser=`whoami` # User running this script
sleeptime=3	 # Time to wait (in seconds) after killing a type of process

# Getting two mandatory paramerters.
taskuser=$1; shift	 # User running Amanda task to kill
task2kill=$1;shift	 # Task to kill

# Running as appropriate user and specifying task to kill is necessary.
if [ ! -z "$task2kill" -a "$runuser" = "$taskuser" ] ; then
    # This task is running? Do amcheck to check it:
    if [ ! -z "$($AMCHECK $task2kill 2>/dev/null | $GREP amcleanup)" ] ; then
	# Enunerating Amanda processes of this task.
        for process in 'amdump' 'driver' 'dumper' 'taper' ;
	do
	    # Getting PIDs for running process instances from process list
	    # and killing them.
    	    $PS aux | $GREP $taskuser | $GREP $task2kill | $GREP $process | \
	              $AWK '{ print $2 }' | while read pid2kill
    	    do
	        echo -e "$MSG_AMANDA_STOP_KILLING $task2kill $process $pid2kill"
		kill $pid2kill
    	    done
	    sleep $sleeptime
	done
	# All relevant processes are killed (I hope).
	# OK, let's clean up, then check it (again).
	# Ignoring errors, only display them.
        $AMCLEANUP $task2kill
	$AMCHECK $task2kill
    fi

# Usage reminder to unappropriate caller.
else
    echo -e "$MSG_AMANDA_STOP_USAGE" >&2
    if [ -n "$taskuser" -a "$runuser" != "$taskuser" ]; then
        echo -e "$MSG_AMANDA_STOP_WRONGUSER $taskuser." >&2
    fi
    exit $EXIT_ERR
fi
