#!/bin/bash
#
# Simple script to correct Amanda virtual tape errors (0 byte files).
# Changes zerofiles to a dummy (but formally regular) one-block length tapefile.
# Part of amanda-server-addons package.

AMANDAGROUP=disk                # Group of Amanda tapes
AMANDAUSER=backup               # User running Amanda
AWK="/usr/bin/awk"              # awk command call
EXIT_ERR="1"                    # Exit code on error

MSG_AMANDA_PURGE_USAGE="Usage: $0 path_to_Amanda_tapedir_to_purge"

# Getting common variables.
HEADERS="/etc/default/amanda-server-addons"
if [ -f "$HEADERS" ]; then . $HEADERS; fi

# Getting a mandatory parameter.
TAPEPATH=$1; shift
if [ -z "$TAPEPATH" ] ; then
    echo -e "$MSG_AMANDA_PURGE_USAGE" >&2; exit $EXIT_ERR
else
    # Enumerating regular files within $TAPEPATH.
    ls $TAPEPATH 2>/dev/null | while read line
    do
	if [ ! -s $TAPEPATH/$line ] ; then
	    # For empty files creating a dummy one block file pair instead.
	    DUMMYFILE=`echo $line | awk -F "." '{print $1}'`.DUMMY.$line
	    DUMMYHEAD=`echo $line | awk -F "." '{print $1}'`-DUMMY.$line
	    # Dummy header.
	    echo '0 0 32768' > $TAPEPATH/$DUMMYHEAD
	    # Dummy tapefile.
	    cat > $TAPEPATH/$DUMMYFILE << "EOF"
AMANDA: FILE 20000101 DUMMY.NOWHERE /DUMMY lev 0 comp .gz program /bin/tar
This is a dummy file to work around Amanda tape error. XXXXXXX
EOF
       	    for i in `seq 1 3263`;
    	    do
		echo -n "XXXXXXXXXX" >> $TAPEPATH/$DUMMYFILE ;
    	    done
	    # Changing files' ownership to $AMANDAUSER when running as root.
	    if [ "`whoami`" = "root" ]; then
		chown $AMANDAUSER:$AMANDAGROUP "$TAPEPATH/$DUMMYHEAD" "$TAPEPATH/$DUMMYFILE" 2>/dev/null
	    fi
	    # Restricting permissions.
	    chmod 600 "$TAPEPATH/$DUMMYHEAD" "$TAPEPATH/$DUMMYFILE" 2>/dev/null
	    # Removing original zero-length file.
	    rm "$TAPEPATH/$line"
	fi
    done
fi
