#!/bin/bash
#
# Simple surveillance script to eliminate zero-length (dummy) tapefiles
# for an entire Amanda task.
# Part of amanda-server-addons package.

AMANDAROOT=/var/backups         # Root directory for Amanda backups
DIRNAME="/usr/bin/dirname"      # dirname command call
EXIT_ERR="1"                    # Exit code on error

MSG_AMANDA_PURGEALL_NOTAPES="Unable to find tapes in"
MSG_AMANDA_PURGEALL_NOSCRIPT="Unable to run"
MSG_AMANDA_PURGEALL_USAGE="Usage: $0 Username_running_Amanda_task Amanda_task_name"
MSG_AMANDA_PURGEALL_WRONGUSER="Please run as"

# Getting common variables.
HEADERS="/etc/default/amanda-server-addons"
if [ -f "$HEADERS" ]; then . $HEADERS; fi

# Local settings (not to override).
# Executable amanda-tape-purge script is mandatory.
purgescript="$($DIRNAME $0)/amanda-tape-purge"
if [ ! -x "$purgescript" ]; then
    echo -e "$MSG_AMANDA_PURGEALL_NOSCRIPT $purgescript!"
    exit $EXIT_ERR
fi

# Getting two mandatory paramerters.
TASKUSER=$1; shift	# User running the Amanda task to correct
TASKPATH=$1; shift	# Path to tapes of Amanda task to correct

# Running as appropriate user and specifying tapes root folder is mandatory.
if [ ! -z "$TASKPATH" -a `whoami` = "$TASKUSER" ] ; then
    # Try relative pathname if absolute isn't valid.
    if [ ! -d "$TASKPATH" ]; then TASKPATH="$AMANDAROOT/$TASKPATH"; fi
    # Giving up on failure.
    if [ ! -d "$TASKPATH" ]; then
	echo -e "$MSG_AMANDA_PURGEALL_NOTAPES $TASKPATH!" >&2; 
	exit $EXIT_ERR
    fi
    # Enumerating tapes.
    ls -L1 $TASKPATH 2>/dev/null | while read TAPEPATH
    do
	# Call purge script for each tape's data folder.
	"$purgescript" "$TASKPATH/$TAPEPATH/data"
    done

# Reminder for wrong callers.
else
    echo -e "$MSG_AMANDA_PURGEALL_USAGE" >&2
    if [ -n "$TASKUSER" -a `whoami` != "$TASKUSER" ]; then
        echo -e "$MSG_AMANDA_PURGEALL_WRONGUSER $TASKUSER!"
    fi
fi
